@@ -132,7 +132,7 @@ class LgbmPISelector(TransformerMixin,Base,BaseTunner):
                 X_tr, X_val, y_tr, y_val = train_test_split(X,y,test_size=self.validation_fraction,random_state=self.random_state,stratify=y)
                 
                 estimator=sLGBMClassifier(random_state=self.random_state,
-                                          n_jobs=effective_n_jobs(self.n_jobs),
+                                          #n_jobs=effective_n_jobs(self.n_jobs),
                                           **self.clf_params).fit(
                     X_tr,y_tr,**self._get_fit_params(X_val,y_val,sample_weight,y.index,y_val.index)
                 )
@@ -140,7 +140,7 @@ class LgbmPISelector(TransformerMixin,Base,BaseTunner):
             else:
                 
                 estimator = sLGBMClassifier(random_state=self.random_state,
-                                            n_jobs=effective_n_jobs(self.n_jobs),
+                                            #n_jobs=effective_n_jobs(self.n_jobs),
                                             **self.clf_params).fit(
                     X,y,**{'sample_weight':sample_weight})  
                                                          
@@ -155,7 +155,7 @@ class LgbmPISelector(TransformerMixin,Base,BaseTunner):
                 self._BayesSearch_CV(para_space,X_tr,y_tr,None if sample_weight is None else sample_weight[y_tr.index])
     
                 estimator=sLGBMClassifier(random_state=self.random_state,
-                                          n_jobs=effective_n_jobs(self.n_jobs),
+                                          #n_jobs=effective_n_jobs(self.n_jobs),
                                           **self.bs_res.best_params_).fit(
                     X_tr,y_tr,**self._get_fit_params(X_val,y_val,sample_weight,y.index,y_val.index)
                 )  
@@ -165,7 +165,7 @@ class LgbmPISelector(TransformerMixin,Base,BaseTunner):
                 self._BayesSearch_CV(para_space,X,y,sample_weight)
                 
                 estimator = sLGBMClassifier(random_state=self.random_state,
-                                            n_jobs=effective_n_jobs(self.n_jobs),
+                                            #n_jobs=effective_n_jobs(self.n_jobs),
                                             **self.bs_res.best_params_).fit(
                     X,y,**{'sample_weight':sample_weight})  
                 
@@ -223,9 +223,11 @@ class LgbmPISelector(TransformerMixin,Base,BaseTunner):
         n_jobs=effective_n_jobs(self.n_jobs)
                         
         bs=BayesSearchCV(
-            sLGBMClassifier(random_state=self.random_state,n_jobs=n_jobs),para_space,cv=cv,
+            sLGBMClassifier(random_state=self.random_state),#,n_jobs=n_jobs
+            para_space,cv=cv,
             n_iter=self.n_iter,n_points=self.init_points,
-            n_jobs=-1 if self.n_jobs==-1 else 1,verbose=self.verbose,refit=False,random_state=self.random_state,
+            n_jobs=n_jobs,#-1 if self.n_jobs==-1 else 1,
+            verbose=self.verbose,refit=False,random_state=self.random_state,
             scoring=scorer,error_score=0)       
         
         self.bs_res=bs.fit(X,y,**{'sample_weight':sample_weight})
@@ -383,7 +385,7 @@ class LgbmShapRFECVSelector(TransformerMixin,Base,BaseTunner):
         if self.method=='raw':
             
             estimator=sLGBMClassifier(random_state=self.random_state,
-                                      n_jobs=effective_n_jobs(self.n_jobs),
+                                      #n_jobs=effective_n_jobs(self.n_jobs),
                                       **self.clf_params)
             
         else:
@@ -391,10 +393,10 @@ class LgbmShapRFECVSelector(TransformerMixin,Base,BaseTunner):
             para_space=self.clf_params if self.clf_params else self._lgbm_hpsearch_default()
     
             
-            estimator=BayesSearchCV(sLGBMClassifier(random_state=self.random_state,n_jobs=n_jobs),para_space,
+            estimator=BayesSearchCV(sLGBMClassifier(random_state=self.random_state),para_space,
                                     n_iter=self.n_iter,n_points=self.n_points,
                                     random_state=self.random_state,
-                                    n_jobs=-1 if self.n_jobs==-1 else 1,
+                                    n_jobs=n_jobs,#-1 if self.n_jobs==-1 else 1,
                                     verbose=self.verbose,cv=cv)
         
         if self.early_stopping_rounds:
@@ -405,7 +407,7 @@ class LgbmShapRFECVSelector(TransformerMixin,Base,BaseTunner):
                                         step=self.step,
                                         random_state=self.random_state,
                                         scoring=self.scoring,
-                                        n_jobs=-1 if self.n_jobs==-1 else 1,
+                                        n_jobs=n_jobs,#-1 if self.n_jobs==-1 else 1,
                                         verbose=-1,
                                         early_stopping_rounds=self.early_stopping_rounds,
                                         cv=cv)
@@ -419,7 +421,7 @@ class LgbmShapRFECVSelector(TransformerMixin,Base,BaseTunner):
                                 step=self.step,
                                 random_state=self.random_state,
                                 scoring=self.scoring,
-                                n_jobs=-1 if self.n_jobs==-1 else 1,
+                                n_jobs=n_jobs,#-1 if self.n_jobs==-1 else 1,
                                 verbose=-1,
                                 cv=cv)
         
@@ -580,7 +582,7 @@ class LgbmSeqSelector(TransformerMixin,Base,BaseTunner):
         
         n_jobs=effective_n_jobs(self.n_jobs)
         
-        lgbm=sLGBMClassifier(random_state=self.random_state,n_jobs=n_jobs,**self.clf_params)
+        lgbm=sLGBMClassifier(random_state=self.random_state,**self.clf_params)
         
         seq_clf = SequentialFeatureSelector(lgbm,                                            
                         k_features=self.k_features,
